Gaussian Overlap (Shape Similarity)
====================================

PyTorch Implementation
~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: shepherd_score.score.gaussian_overlap
   :members:
   :undoc-members:
   :show-inheritance:

NumPy Implementation
~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.gaussian_overlap_np
   :members:
   :undoc-members:
   :show-inheritance:

JAX Implementation
~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.gaussian_overlap_jax
   :members:
   :undoc-members:
   :show-inheritance:
